<?php

namespace Drupal\Tests\comment_notify\Functional;

/**
 * Tests that all the notifications are sent as expected.
 *
 * @group comment_notify
 */
class CommentNotifyNotificationsTest extends CommentNotifyTestBase {

  /**
   * The permissions required by the tests.
   *
   * @var array
   */
  protected $permissions = [
    'access comments',
    'access content',
    'edit own comments',
    'post comments',
    'skip comment approval',
    'subscribe to comments',
  ];

  /**
   * Tests that the Mail notification is sent properly and it is only send once.
   */
  public function testCommentNotification() {
    $user1 = $this->drupalCreateUser($this->permissions);
    comment_notify_set_user_notification_setting($user1->id(), COMMENT_NOTIFY_NODE, COMMENT_NOTIFY_COMMENT);
    $user2 = $this->drupalCreateUser($this->permissions);
    $node = $this->drupalCreateNode(
      [
        'type' => 'article',
        'uid' => $user1,
      ]
    );
    $this->drupalLogin($user2);
    $comment = $this->postComment(
      $node->toUrl()->toString(),
      $this->randomMachineName(),
      $this->randomMachineName(),
      ['notify' => TRUE, 'notify_type' => COMMENT_NOTIFY_NODE]
    );
    // Test that the notification was sent.
    $this->assertMail('to', $user1->getEmail(), t('Message was sent to the user.'));
    $this->container->get('state')->set('system.test_mail_collector', []);

    // Edit the comment, no notification must be sent.
    $this->drupalGet('comment/' . $comment['id'] . '/edit');
    $this->getSession()->getPage()->fillField(t('Comment'), $this->randomMachineName());
    $this->getSession()->getPage()->pressButton(t('Save'));
    $captured_emails = $this->container->get('state')->get('system.test_mail_collector');
    $this->assertEmpty($captured_emails, 'No notifications has been sent.');
    $this->drupalLogout();

  }

}
